import React from "react"
import { useStaticQuery, graphql } from "gatsby"

import CardList from "./core/CardList"
import Button from "./core/Button"

// Ineherit type from cardlist ?
interface INews {
    title?: string
    action?: {
        name?: string
        url?: string
        classname?: string
    }
    anime?: boolean
    layout?: "row" | "col" | "grid"
    size?: "xs" | "base" | "xl"
}

const News = (props: INews) => {
    const data = useStaticQuery(graphql`
        query getNews {
            directus {
                news(
                    limit: 3
                    filter: { status: { _eq: "published" } }
                    sort: ["-pinned", "-date_published"]
                ) {
                    id
                    slug
                    content
                    title
                    date_published
                    image {
                        id
                        imageFile {
                            childImageSharp {
                                gatsbyImageData
                            }
                        }
                    }
                }
            }
        }
    `)

    const {
        title = "",
        anime = true,
        action,
        size = "xs",
        layout = "grid",
    } = props

    const news = data.directus.news.map((dtNew) => {
        return {
            name: dtNew.title,
            description: dtNew.content,
            image: dtNew.image?.imageFile,
            url: "/news/" + dtNew.slug,
            size: size,
        }
    })

    return (
        <div>
            <h2 className="mt-2 mb-8 text-3xl font-extrabold tracking-tight sm:text-4xl">
                {title}
            </h2>
            <CardList cards={news} layout={layout} anime={anime} />
            <div className="mt-8 flex justify-center">
                {action && <Button {...action} />}
            </div>
        </div>
    )
}

export default News
